from __future__ import annotations

# now: 448~2785
# with invalid height, horizontal lines appears
HEIGHT_GAP: dict[int, int] = {
    448: 0,
    472: 24,
    480: 0,
    584: 6,
    626: 18,
    670: 28,
    700: 25,
    774: 6,
    798: 28,
    960: 0,
    1000: 6,
    1024: 0,
    1076: 18,
    1129: 8,
    1133: 10,
    1137: 14,
    1142: 20,
    1143: 21,
    1149: 26,
    1163: 8,
    1200: 16,
    1236: 18,
    1300: 17,
    1378: 0,
    1400: 22,
    1536: 0,
    1593: 22,
    1600: 0,
    1811: 16,
    1826: 0,
    1920: 0,
    2000: 16,
    2048: 0,
    2062: 12,
    2100: 18,
}


# now: 332~1480
# with invalid width, vartical lines appears
WIDTH_GAP: dict[int, int] = {
    332: 10,
    426: 8,
    438: 20,
    475: 24,
    575: 29,
    656: 14,
    658: 16,
    667: 24,
    682: 8,
    690: 16,
    698: 24,
    704: 0,
    712: 8,
    713: 6,
    717: 10,
    720: 15,
    721: 14,
    725: 18,
    760: 24,
    764: 25,
    800: 0,
    818: 16,
    820: 20,
    822: 22,
    829: 26,
    836: 4,
    840: 8,
    844: 10,
    847: 12,
    848: 14,
    850: 16,
    862: 30,
    921: 22,
    958: 27,
    960: 0,
    980: 18,
    1037: 10,
    1042: 16,
    1061: 4,
    1070: 12,
    1073: 14,
    1080: 22,
    1084: 26,
    1085: 26,
    1091: 0,
    1093: 2,
    1096: 8,
    1097: 6,
    1103: 12,
    1108: 18,
    1109: 20,
    1100: 10,
    1114: 23,
    1115: 24,
    1120: 0,
    1121: 0,
    1124: 2,
    1125: 2,
    1126: 4,
    1127: 5,
    1128: 6,
    1133: 10,
    1326: 12,
    1350: 4,
    1353: 8,
    1394: 16,
    1408: 0,
    1414: 4,
    1440: 0,
    1441: 0,
    1443: 0,
    1444: 2,
    1445: 2,
    1453: 10,
    1480: 6,
}
